@@ -27,7 +27,7 @@ use strict;
 
 use AnyEvent ();
 
-use Event qw(time); # we have to importt something to make Event use Time::HiRes
+use Event qw(unloop); # we have to import something to make Event use Time::HiRes
 
 sub io {
    my ($class, %arg) = @_;
@@ -38,6 +38,7 @@ sub io {
 
 sub timer {
    my ($class, %arg) = @_;
+   $arg{after} = 0 if $arg{after} < 0;
    bless \Event->timer (%arg, repeat => $arg{interval}), $class
 }
 
@@ -46,6 +47,11 @@ sub signal {
    bless \Event->signal (%arg), $class
 }
 
+sub idle {
+   my ($class, %arg) = @_;
+   bless \Event->idle (repeat => 1, min => 0, %arg), $class
+}
+
 sub DESTROY {
    ${$_[0]}->cancel;
 }
